# Security Policy

## Supported Versions

I plan to release security updates for the latest stable version of `desto`. Please always use the latest version for the best security and support.

| Version | Supported          |
| ------- | ----------------- |
| latest  | :white_check_mark: |
| < latest| :x:                |

## Reporting a Vulnerability

If you discover a security vulnerability in this project, **please do not create a public issue**. Instead, report it privately by emailing:

[ikalfas@protonmail.com](mailto:ikalfas+vrestosec@protonmail.com)

Please include as much detail as possible to help me quickly understand and address the issue. I will respond as soon as possible and coordinate a fix and disclosure process as appropriate.

- I appreciate responsible disclosure.
- After a fix is released, I will credit reporters (if desired) in the release notes.
